@@ -1,4 +1,4 @@
-package App::MBUtiny; # $Id: MBUtiny.pm 50 2014-09-03 12:24:39Z abalama $
+package App::MBUtiny; # $Id: MBUtiny.pm 54 2014-09-04 11:57:33Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::MBUtiny - BackUp system for Your WEBsites
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 use CTK::Util;
 use CTK::ConfGenUtil;
@@ -385,8 +385,10 @@ sub backup {
             # Step 04b.       FTP      
             $step = "Step 04b."; $c->log_debug($pfx, $step, "Files on the first FTP storage");
             my $ftp_node = _node2anode(node($job, $hostname => 'ftp'));
-            my $useftp = value($ftp_node->[0], 'ftphost') ? 1 : 0;
-            my $ftplist = $useftp ? ftpgetlist($ftp_node->[0], qr/^[^.]/) : [];
+            my $ftpct_first = $ftp_node->[0];
+            _ftpattr_set($ftpct_first);
+            my $useftp = value($ftpct_first, 'ftphost') ? 1 : 0;
+            my $ftplist = $useftp ? ftpgetlist($ftpct_first, qr/^[^.]/) : [];
             my @ftpfiles = sort {$a cmp $b} @$ftplist;
             $c->log_debug($pfx, sprintf(" - %s",$_)) foreach @ftpfiles;
             $c->log_debug($pfx x 2, "SKIPPED") unless $useftp;
@@ -466,6 +468,7 @@ sub backup {
             $step = "Step 05b."; $c->log_debug($pfx, $step, "Delete old backups on FTP storage");
             if ($useftp) {
                 foreach my $ftpct (@$ftp_node) {
+                    _ftpattr_set($ftpct);
                     my $ftph = ftp($ftpct, 'connect');
                     my $ftpuri = sprintf("ftp://%s\@%s/%s", value($ftpct, 'ftpuser'), value($ftpct, 'ftphost'), value($ftpct, 'ftpdir'));
                     unless ($ftph) {
@@ -630,6 +633,7 @@ sub backup {
             if ($useftp) {
                 foreach my $ftpct (@$ftp_node) {
                     next if value($ftpct, 'skip');
+                    _ftpattr_set($ftpct);
                     my $ftpuri = sprintf("ftp://%s\@%s/%s", value($ftpct, 'ftpuser') || '', value($ftpct, 'ftphost') || '', value($ftpct, 'ftpdir') || '');
                     $c->store(
                         -connect  => $ftpct,
@@ -785,7 +789,7 @@ sub backup {
                 $ma{'-message'} .= "\n---\n"
                                  . sprintf("Generated by    : MBUtiny %s\n", $VERSION)
                                  . sprintf("Date generation : %s\n", localtime2date_time())
-                                 . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 50 2014-09-03 12:24:39Z abalama $')
+                                 . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 54 2014-09-04 11:57:33Z abalama $')
                                  . sprintf("Time Stamp      : %s\n", CTK::tms())
                                  . sprintf("Configuration   : %s\n", $c->cfgfile);
                 $ma{'-attach'} = _attach($ma{'-attach'}) || [];
@@ -980,6 +984,8 @@ sub test {
         my $ftp_node = _node2anode(node($job, $hostname => 'ftp'));
         foreach my $ftpct (@$ftp_node) {
             if (value($ftpct, 'ftphost')) {
+                _ftpattr_set($ftpct);
+                #::debug(Dumper($ftpct));
                 my $ftpuri = sprintf("ftp://%s\@%s/%s", value($ftpct, 'ftpuser'), value($ftpct, 'ftphost'), value($ftpct, 'ftpdir'));
                 my $ftplist = ftpgetlist($ftpct, qr/^[^.]/) || [];
                 my @ftpfiles = sort {$a cmp $b} @$ftplist;
@@ -1063,7 +1069,7 @@ sub test {
         $ma{'-message'} .= "\n---\n"
             . sprintf("Generated by    : MBUtiny %s\n", $VERSION)
             . sprintf("Date generation : %s\n", localtime2date_time())
-            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 50 2014-09-03 12:24:39Z abalama $')
+            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 54 2014-09-04 11:57:33Z abalama $')
             . sprintf("Time Stamp      : %s\n", CTK::tms())
             . sprintf("Configuration   : %s\n", $c->cfgfile);
         $ma{'-attach'} = _attach($ma{'-attach'}) || [];
@@ -1252,6 +1258,7 @@ sub restore {
                 my $ftp_node = _node2anode(node($job, $hostname => 'ftp'));
                 my $tryftp;
                 foreach my $ftpct (@$ftp_node) {
+                    _ftpattr_set($ftpct);
                     my $ftpuri = sprintf("ftp://%s\@%s/%s", value($ftpct, 'ftpuser'), value($ftpct, 'ftphost'), value($ftpct, 'ftpdir'));
                     my $ftph = ftp($ftpct, 'connect');
                     if ($ftph) {
@@ -1260,7 +1267,7 @@ sub restore {
                         $c->log_error($pfx x 2, sprintf("ERROR: Can't connect to remote FTP server %s", $ftpuri));
                         next;
                     };
-                    my $ftplist = ftpgetlist($ftp_node->[0], qr/^[^.]/);
+                    my $ftplist = ftpgetlist($ftpct, qr/^[^.]/);
                     $tryftp = _search_file($ftplist, $find_file);
                     if ($tryftp) { #  ! ! 
                         my $file_dst = catfile($target_dir,$tryftp);
@@ -1678,6 +1685,18 @@ sub _search_file { #
     }
     return $s
 }
+sub _ftpattr_set {
+    my $in = shift;
+    my $attr = array($in => "set");
+    my %attrs;
+    foreach (@$attr) {
+        $attrs{$1} = $2 if $_ =~ /^\s*(\S+)\s+(.+)$/;
+    }
+    if ($in && ref($in) eq 'HASH') {
+        $in->{ftpattr} = {%attrs};
+    } 
+    return;
+}
 
 1;
 
